summaryrefslogtreecommitdiffstats
path: root/libktorrent/torrent/bencoder.h
diff options
context:
space:
mode:
Diffstat (limited to 'libktorrent/torrent/bencoder.h')
-rw-r--r--libktorrent/torrent/bencoder.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libktorrent/torrent/bencoder.h b/libktorrent/torrent/bencoder.h
index 8760d14..eb84c39 100644
--- a/libktorrent/torrent/bencoder.h
+++ b/libktorrent/torrent/bencoder.h
@@ -58,14 +58,14 @@ namespace bt
};
/**
* Write the output of a BEncoder to a QByteArray
*/
class BEncoderBufferOutput : public BEncoderOutput
{
- QByteArray & data;
+ TQByteArray & data;
Uint32 ptr;
public:
- BEncoderBufferOutput(QByteArray & data);
+ BEncoderBufferOutput(TQByteArray & data);
void write(const char* str,Uint32 len);
};
@@ -124,13 +124,13 @@ namespace bt
* Write a string
* @param str
*/
- void write(const QString & str);
+ void write(const TQString & str);
/**
- * Write a QByteArray
+ * Write a TQByteArray
* @param data
*/
- void write(const QByteArray & data);
+ void write(const TQByteArray & data);
/**
* Write a data array
@@ -58,14 +58,14 @@ namespace bt
};
/**
- * Write the output of a BEncoder to a QByteArray
+ * Write the output of a BEncoder to a TQByteArray
*/
class BEncoderBufferOutput : public BEncoderOutput